emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] emacs-25 acae275: ; Spelling fixes


From: Paul Eggert
Subject: [Emacs-diffs] emacs-25 acae275: ; Spelling fixes
Date: Fri, 4 Nov 2016 21:51:04 +0000 (UTC)

branch: emacs-25
commit acae275b2752357497a2411876b83240ce7c8aec
Author: Paul Eggert <address@hidden>
Commit: Paul Eggert <address@hidden>

    ; Spelling fixes
---
 ChangeLog.2                         |    2 +-
 doc/misc/ChangeLog.1                |    2 +-
 etc/ERC-NEWS                        |    2 +-
 etc/NEWS.23                         |    2 +-
 etc/TODO                            |    2 +-
 lisp/cedet/ede/locate.el            |    4 ++--
 lisp/cedet/semantic/db-typecache.el |    2 +-
 lisp/emacs-lisp/eieio-core.el       |    2 +-
 lisp/emulation/edt.el               |    2 +-
 lisp/erc/erc-backend.el             |    6 +++---
 lisp/international/ucs-normalize.el |    2 +-
 lisp/isearch.el                     |    2 +-
 lisp/language/ind-util.el           |    2 +-
 lisp/mh-e/mh-search.el              |    4 ++--
 lisp/mh-e/mh-thread.el              |    8 ++++----
 lisp/subr.el                        |    2 +-
 nt/README.W32                       |    2 +-
 src/emacs.c                         |    2 +-
 src/lread.c                         |    8 ++++----
 19 files changed, 29 insertions(+), 29 deletions(-)

diff --git a/ChangeLog.2 b/ChangeLog.2
index 79f44fd..42ea75f 100644
--- a/ChangeLog.2
+++ b/ChangeLog.2
@@ -15098,7 +15098,7 @@
        * lisp/files.el: Don't allow customization of dir-locals sorting.
        In retrospect, this is not a good idea for the same reason that
        `dir-locals-file' is a defconst, because it is important that this
-       behaviour be "uniform across different environments and users".
+       behavior be "uniform across different environments and users".
        Sure, the user can still change the sorting with a hack, but we
        shouldn't encourage them to change it.
        (dir-locals--all-files): Return list in the order returned by
diff --git a/doc/misc/ChangeLog.1 b/doc/misc/ChangeLog.1
index eb16d4a..93aacb5 100644
--- a/doc/misc/ChangeLog.1
+++ b/doc/misc/ChangeLog.1
@@ -5331,7 +5331,7 @@
 
 2010-07-09  Michael Albinus  <address@hidden>
 
-       * dbus.texi (Top): Introduce Index.  Emphasize "nil" whereever
+       * dbus.texi (Top): Introduce Index.  Emphasize "nil" wherever
        forgotten.
        (Type Conversion): Precise conversion of natural numbers.
        (Errors and Events): Add "debugging" to concept index.  Add variable
diff --git a/etc/ERC-NEWS b/etc/ERC-NEWS
index 13827c6..69b8468 100644
--- a/etc/ERC-NEWS
+++ b/etc/ERC-NEWS
@@ -1077,7 +1077,7 @@ major changes for implementers, and module writers:
     corresponding hook variables.
 
     The mapping of server commands to hook variables is no longer
-    done via `erc-event-to-hook', but through an #'equal hashtable,
+    done via `erc-event-to-hook', but through an #'equal hash table,
     `erc-server-responses'.  In order to find a hook you do:
 
     (erc-get-hook command)
diff --git a/etc/NEWS.23 b/etc/NEWS.23
index d92bf23..f74141d 100644
--- a/etc/NEWS.23
+++ b/etc/NEWS.23
@@ -551,7 +551,7 @@ System (CLOS).  It is used by the other CEDET packages.
 
 ** js.el is a new major mode for JavaScript files.
 
-** imap-hash.el is a new library to address IMAP mailboxes as hashtables.
+** imap-hash.el is a new library to address IMAP mailboxes as hash tables.
 
 
 * Incompatible Lisp Changes in Emacs 23.2
diff --git a/etc/TODO b/etc/TODO
index fe0e2ac..48c1654 100644
--- a/etc/TODO
+++ b/etc/TODO
@@ -38,7 +38,7 @@ stay within exec_byte_code.
 ** Add new 'switch' byte-code
 This byte-code would take one argument from the stack (the object to test)
 and one argument from the constant-pool (a switch table, implemented as an
-eq-hashtable) and would jump to the "label" contained in the hashtable.
+'eq' hash table) and would jump to the "label" contained in the hash table.
 
 Then add a 'case' special-form that can be compiled to this byte-code.
 This would behave just like cl-case, but instead of expanding to cond+eq it
diff --git a/lisp/cedet/ede/locate.el b/lisp/cedet/ede/locate.el
index 38d2388..8564719 100644
--- a/lisp/cedet/ede/locate.el
+++ b/lisp/cedet/ede/locate.el
@@ -124,12 +124,12 @@ based on `ede-locate-setup-options'."
   t)
 
 (cl-defmethod ede-locate-flush-hash ((loc ede-locate-base))
-  "For LOC, flush hashtable and start from scratch."
+  "For LOC, flush hash table and start from scratch."
   (oset loc hash (make-hash-table :test 'equal)))
 
 (cl-defmethod ede-locate-file-in-hash ((loc ede-locate-base)
                                    filestring)
-  "For LOC, is the file FILESTRING in our hashtable?"
+  "For LOC, is the file FILESTRING in our hash table?"
   (gethash filestring (oref loc hash)))
 
 (cl-defmethod ede-locate-add-file-to-hash ((loc ede-locate-base)
diff --git a/lisp/cedet/semantic/db-typecache.el 
b/lisp/cedet/semantic/db-typecache.el
index 366af60..76382a3 100644
--- a/lisp/cedet/semantic/db-typecache.el
+++ b/lisp/cedet/semantic/db-typecache.el
@@ -56,7 +56,7 @@
    (stream :initform nil
           :documentation
           "The searchable tag stream for this cache.
-NOTE: Can I get rid of this?  Use a hashtable instead?")
+NOTE: Can I get rid of this?  Use a hash table instead?")
    (dependants :initform nil
               :documentation
               "Any other object that is dependent on typecache results.
diff --git a/lisp/emacs-lisp/eieio-core.el b/lisp/emacs-lisp/eieio-core.el
index 223c2a6..5454dfc 100644
--- a/lisp/emacs-lisp/eieio-core.el
+++ b/lisp/emacs-lisp/eieio-core.el
@@ -459,7 +459,7 @@ See `defclass' for more information."
                           (cl--slot-descriptor-initform (aref slots i)))))
       (setf (eieio--class-class-allocation-values newc) v))
 
-    ;; Attach slot symbols into a hashtable, and store the index of
+    ;; Attach slot symbols into a hash table, and store the index of
     ;; this slot as the value this table.
     (let* ((slots (eieio--class-slots newc))
           ;; (cslots (eieio--class-class-slots newc))
diff --git a/lisp/emulation/edt.el b/lisp/emulation/edt.el
index 6bda15b..f408ff7 100644
--- a/lisp/emulation/edt.el
+++ b/lisp/emulation/edt.el
@@ -497,7 +497,7 @@ Argument NUM is the number of EOL marks to move."
 ;;; of line, etc.) it takes a bit of special handling.
 ;;;
 ;;; The variable edt-word-entities contains a list of characters which
-;;; are to be viewed as distinct words where ever they appear in the
+;;; are to be viewed as distinct words wherever they appear in the
 ;;; buffer.  This emulates the EDT line mode command SET ENTITY WORD.
 
 
diff --git a/lisp/international/ucs-normalize.el 
b/lisp/international/ucs-normalize.el
index 74978ce..1e247c5 100644
--- a/lisp/international/ucs-normalize.el
+++ b/lisp/international/ucs-normalize.el
@@ -227,7 +227,7 @@
     table))
 
 (defvar ucs-normalize-decomposition-pair-to-primary-composite nil
-  "Hashtable of decomposed pair to primary composite.
+  "Hash table of decomposed pair to primary composite.
 Note that Hangul are excluded.")
   (setq ucs-normalize-decomposition-pair-to-primary-composite
         (ucs-normalize-make-hash-table-from-alist
diff --git a/lisp/isearch.el b/lisp/isearch.el
index 0181951..ff77930 100644
--- a/lisp/isearch.el
+++ b/lisp/isearch.el
@@ -562,7 +562,7 @@ The symbol property `isearch-message-prefix' put on this 
function
 specifies the prefix string displayed in the search message.
 
 This variable is set and changed during isearch.  To change the
-default behaviour used for searches, see `search-default-mode'
+default behavior used for searches, see `search-default-mode'
 instead.")
 ;; We still support setting this to t for backwards compatibility.
 (define-obsolete-variable-alias 'isearch-word
diff --git a/lisp/language/ind-util.el b/lisp/language/ind-util.el
index deea489..f7424ec 100644
--- a/lisp/language/ind-util.el
+++ b/lisp/language/ind-util.el
@@ -39,7 +39,7 @@
 (eval-and-compile
 
 (defun indian-regexp-of-hashtbl-keys (hashtbl)
-  "Returns the regular expression of hashtable keys."
+  "Return the regular expression of hash table keys."
   (let (keys)
     (maphash (lambda (key val) (push key keys)) hashtbl)
     (regexp-opt keys)))
diff --git a/lisp/mh-e/mh-search.el b/lisp/mh-e/mh-search.el
index 6e60744..d5a2d77 100644
--- a/lisp/mh-e/mh-search.el
+++ b/lisp/mh-e/mh-search.el
@@ -1859,7 +1859,7 @@ PROC is used to convert the value to actual data."
 (defun mh-index-update-maps (folder &optional origin-map)
   "Annotate all as yet unannotated messages in FOLDER with their MD5 hash.
 As a side effect msg -> checksum map is updated. Optional
-argument ORIGIN-MAP is a hashtable which maps each message in the
+argument ORIGIN-MAP is a hash table which maps each message in the
 index folder to the original folder and message from whence it
 was copied. If present the checksum -> (origin-folder,
 origin-index) map is updated too."
@@ -1913,7 +1913,7 @@ origin-index) map is updated too."
 (defun mh-index-update-single-msg (msg checksum origin-map)
   "Update various maps for one message.
 MSG is a index folder message, CHECKSUM its MD5 hash and
-ORIGIN-MAP, if non-nil, a hashtable containing which maps each
+ORIGIN-MAP, if non-nil, a hash table containing which maps each
 message in the index folder to the folder and message that it was
 copied from. The function updates the hash tables
 `mh-index-msg-checksum-map' and `mh-index-checksum-origin-map'.
diff --git a/lisp/mh-e/mh-thread.el b/lisp/mh-e/mh-thread.el
index e6acdba..2a37cfc 100644
--- a/lisp/mh-e/mh-thread.el
+++ b/lisp/mh-e/mh-thread.el
@@ -89,11 +89,11 @@
   (real-child-p t))
 
 (defvar mh-thread-id-hash nil
-  "Hashtable used to canonicalize message identifiers.")
+  "Hash table used to canonicalize message identifiers.")
 (make-variable-buffer-local 'mh-thread-id-hash)
 
 (defvar mh-thread-subject-hash nil
-  "Hashtable used to canonicalize subject strings.")
+  "Hash table used to canonicalize subject strings.")
 (make-variable-buffer-local 'mh-thread-subject-hash)
 
 (defvar mh-thread-id-table nil
@@ -109,11 +109,11 @@
 (make-variable-buffer-local 'mh-thread-id-index-map)
 
 (defvar mh-thread-subject-container-hash nil
-  "Hashtable used to group messages by subject.")
+  "Hash table used to group messages by subject.")
 (make-variable-buffer-local 'mh-thread-subject-container-hash)
 
 (defvar mh-thread-duplicates nil
-  "Hashtable used to associate messages with the same message identifier.")
+  "Hash table used to associate messages with the same message identifier.")
 (make-variable-buffer-local 'mh-thread-duplicates)
 
 (defvar mh-thread-history ()
diff --git a/lisp/subr.el b/lisp/subr.el
index 07909b8..efea412 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -903,7 +903,7 @@ KEY is a string or vector representing a sequence of 
keystrokes."
 
 (defun substitute-key-definition (olddef newdef keymap &optional oldmap prefix)
   "Replace OLDDEF with NEWDEF for any keys in KEYMAP now defined as OLDDEF.
-In other words, OLDDEF is replaced with NEWDEF where ever it appears.
+In other words, OLDDEF is replaced with NEWDEF wherever it appears.
 Alternatively, if optional fourth argument OLDMAP is specified, we redefine
 in KEYMAP as NEWDEF those keys which are defined as OLDDEF in OLDMAP.
 
diff --git a/nt/README.W32 b/nt/README.W32
index 4149c3b..d866d9f 100644
--- a/nt/README.W32
+++ b/nt/README.W32
@@ -50,7 +50,7 @@ See the end of the file for license conditions.
   page.
 
   Emacs is completely portable. You can create your own shortcut to
-  runemacs.exe and place this where ever you find it convienient, or
+  runemacs.exe and place this wherever you find it convenient, or
   run it from a USB or network drive without copying or installing
   anything on the machine itself.
 
diff --git a/src/emacs.c b/src/emacs.c
index 2480dfc..f8d5dfa 100644
--- a/src/emacs.c
+++ b/src/emacs.c
@@ -1167,7 +1167,7 @@ Using an Emacs configured with --with-x-toolkit=lucid 
does not have this problem
 
       /* Called before syms_of_fileio, because it sets up Qerror_condition.  */
       syms_of_data ();
-      syms_of_fns ();     /* Before syms_of_charset which uses hashtables.  */
+      syms_of_fns ();  /* Before syms_of_charset which uses hash tables.  */
       syms_of_fileio ();
       /* Before syms_of_coding to initialize Vgc_cons_threshold.  */
       syms_of_alloc ();
diff --git a/lisp/erc/erc-backend.el b/lisp/erc/erc-backend.el
index 6d508e2..012b5b5 100644
--- a/lisp/erc/erc-backend.el
+++ b/lisp/erc/erc-backend.el
@@ -108,7 +108,7 @@
 ;;;; Variables and options
 
 (defvar erc-server-responses (make-hash-table :test #'equal)
-  "Hashtable mapping server responses to their handler hooks.")
+  "Hash table mapping server responses to their handler hooks.")
 
 (cl-defstruct (erc-response (:conc-name erc-response.))
   (unparsed "" :type string)
@@ -1064,7 +1064,7 @@ See also `erc-server-responses'."
 (defun erc-call-hooks (process message)
   "Call hooks associated with MESSAGE in PROCESS.
 
-Finds hooks by looking in the `erc-server-responses' hashtable."
+Finds hooks by looking in the `erc-server-responses' hash table."
   (let ((hook (or (erc-get-hook (erc-response.command message))
                   'erc-default-server-functions)))
     (run-hook-with-args-until-success hook process message)
@@ -1220,7 +1220,7 @@ add things to `%s' instead."
        (put ',fn-name 'definition-name ',name)
        (put ',hook-name 'definition-name ',name)
 
        ;; Hashtable map of responses to hook variables
        ,@(cl-loop for response in (cons name aliases)
                   for var in (cons hook-name var-alternates)
                   collect `(puthash ,(format "%s" response) ',var
@@ -1220,7 +1220,7 @@ add things to `%s' instead."
        (put ',hook-name 'definition-name ',name)
 
-       ;; Hashtable map of responses to hook variables
+       ;; Hash table map of responses to hook variables
        ,@(cl-loop for response in (cons name aliases)
                   for var in (cons hook-name var-alternates)
diff --git a/src/lread.c b/src/lread.c
index 8a36880..0bc34b2 100644
--- a/src/lread.c
+++ b/src/lread.c
@@ -2500,7 +2500,7 @@ read1 (Lisp_Object readcharfun, int *pch, bool 
first_in_list)
          c = READCHAR;
          if (c == '(')
            {
              /* Accept extended format for hashtables (extensible to
                 other types), e.g.
                 #s(hash-table size 2 test equal data (k1 v1 k2 v2))  */
              Lisp_Object tmp = read_list (0, readcharfun);
@@ -2546,10 +2546,10 @@ read1 (Lisp_Object readcharfun, int *pch, bool 
first_in_list)
              if (!NILP (params[param_count + 1]))
                param_count += 2;
 
-             /* This is the hashtable data.  */
+             /* This is the hash table data.  */
              data = Fplist_get (tmp, Qdata);
 
              /* Now use params to make a new hashtable and fill it.  */
              ht = Fmake_hash_table (param_count, params);
 
              while (CONSP (data))
@@ -2557,7 +2557,7 @@ read1 (Lisp_Object readcharfun, int *pch, bool 
first_in_list)
                  key = XCAR (data);
                  data = XCDR (data);
                  if (!CONSP (data))
-                   error ("Odd number of elements in hashtable data");
+                   error ("Odd number of elements in hash table data");
                  val = XCAR (data);
                  data = XCDR (data);
                  Fputhash (key, val, ht);
@@ -2500,7 +2500,7 @@ read1 (Lisp_Object readcharfun, int *pch, bool 
          if (c == '(')
            {
-             /* Accept extended format for hashtables (extensible to
+             /* Accept extended format for hash tables (extensible to
                 other types), e.g.
                 #s(hash-table size 2 test equal data (k1 v1 k2 v2))  */
@@ -2546,10 +2546,10 @@ read1 (Lisp_Object readcharfun, int *pch, bool 
              data = Fplist_get (tmp, Qdata);
 
-             /* Now use params to make a new hashtable and fill it.  */
+             /* Now use params to make a new hash table and fill it.  */
              ht = Fmake_hash_table (param_count, params);
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]